@@ -316,7 +316,7 @@ class Scan:
         iterator = _get_iterator(unp.nominal_values(self.q), progress)
         to_remove = []
         for i in iterator:
-            if self.data['roi1_maxval'] > self.pixel_max:
+            if self.data['roi1_maxval'][i] > self.pixel_max:
                 to_remove.append(i)
                 continue
             im = image.Image(self.data["file"][i], self.data, self.metadata, hot_pixel_threshold=self.hot_pixel_threshold)
